diff --git a/lib/TemplateRender.php b/lib/TemplateRender.php
index f761b86..0ce9ba7 100644
--- a/lib/TemplateRender.php
+++ b/lib/TemplateRender.php
@@ -59,7 +59,7 @@ class TemplateRender extends PageRender {
$this->layout['action'] = '
| %s | ';
$this->layout['actionajax'] = ' | %s | ';
# If we dont want to render this template automatically, we'll return here.
if ($norender)
return;
@@ -273,7 +273,7 @@ class TemplateRender extends PageRender {
else
$container = $args[5];
- # Process filter (arg 1), eventually replace %attr% by it's value set in a previous page.
+ # Process filter (arg 1), eventually replace %attr% by its value set in a previous page.
preg_match_all('/%(\w+)(\|.+)?(\/[lUC])?%/U',$args[1],$filtermatchall);
//print_r($matchall); // -1 = highlevel match, 1 = attr, 2 = subst, 3 = mod
@@ -1679,7 +1679,7 @@ function validateForm(silence) {
// Sometimes the alert gives us enough time!
if (typeof getAttributeComponents != "undefined")
- alert("Dont bother, our JS is loaded now!");
+ alert("Don't bother, our JS is loaded now!");
}
validateForm(true);
@@ -59,7 +59,7 @@ class TemplateRender extends PageRender {
| %s | ';
$this->layout['actionajax'] = ' | %s | ';
- # If we dont want to render this template automatically, we'll return here.
+ # If we don't want to render this template automatically, we'll return here.
if ($norender)
return;